@@ -1,4 +1,4 @@
-# $Id: DSA.pm,v 1.5 2001/08/06 07:30:48 btrott Exp $
+# $Id: DSA.pm,v 1.6 2001/08/13 01:18:21 btrott Exp $
 
 package Crypt::OpenPGP::Key::Secret::DSA;
 use strict;
@@ -10,7 +10,7 @@ use Crypt::OpenPGP::ErrorHandler;
 use base qw( Crypt::OpenPGP::Key::Secret Crypt::OpenPGP::ErrorHandler );
 
 sub secret_props { qw( x ) }
-sub sig_props { qw( r s ) }
+*sig_props = \&Crypt::OpenPGP::Key::Public::DSA::sig_props;
 *public_props = \&Crypt::OpenPGP::Key::Public::DSA::public_props;
 *size = \&Crypt::OpenPGP::Key::Public::DSA::size;
 *keygen = \&Crypt::OpenPGP::Key::Public::DSA::keygen;
